Attribute VB_Name = "Remote"
'********************************************************************
'   Remote.bas
'       -Contains global variables and global function calls used by
'           the application.
'
'   Created by: Zac M. Leider
'   Date: May 5th, 2003
'   Project: PC Remote Control (SNC Senior Capstone '03)
'
'********************************************************************

' data structure of one remote button
'   code = 6 byte signal
'   func = its associated function (7,PLAY,POWER,...)
'   act = action it is bound with (PLAY -> Play WinAmp)
Public Type Key
    code As String
    func As String
    act As String
End Type

' data structure of one remote
'   name = name of the remote
'   bcount = number of keys you have programmed it to recognize
'   Button(200) = array of all the programmed keys
Public Type Remote
    name As String
    bcount As Integer
    Button(200) As Key
End Type

' data structure of a point (x,y) - used for mouse movements
Public Type POINTAPI
   X As Long
   Y As Long
End Type

' constants used for moving the mouse in the mouse_event API call
Const MOUSE_MOVE = &H1
Const MOUSE_LEFTDOWN = &H2
Const MOUSE_LEFTUP = &H4
Const MOUSE_RIGHTDOWN = &H8
Const MOUSE_RIGHTUP = &H10
Const MOUSE_MIDDLEDOWN = &H20
Const MOUSE_MIDDLEUP = &H40
Const MOUSE_ABSOLUTE = &H8000

' handles to different applications
Public hWord As Long        'Microsoft Word
Public hPP As Long          'Microsoft PowerPoint
Public hExplorer As Long    'Internet Explorer
Public hPaint As Long       'Paint
Public hCalc As Long        'Calculator
Public hIM As Long          'AOL Instant Messenger

'Used for cycling windows - just an example, not fully functional
' * would be good extension to make work for all windows, being able to cycle
'       through them and close, minimize/maximize and such
' right now, application only cycles through Calculator, Word,
'       Powerpoint, Explorer, and itself (History Frame)
Public Windows(10) As Long
Public WindowsCount As Integer
Public WindowsPointer As Integer

' Used for text to speech commands to remote errors and give instructions
'###################### UNCOMMENT FOR SPEECH ########################
'Public Voice As SpVoice
'####################################################################

' Array of programmed remotes and a counter to keep track of how many
Public StoredRemote(5) As Remote
Public rcount As Integer

' These are used to program timed keys, for example the mouse moves
' faster if the programmed key is pressed so many times in a given
' time interval.  Also used with the text calls (abcABC)
Public SameCount As Integer
Public Previous As String
Public TimeOut As Boolean

Public commopen As Boolean 'signals that the comm port is open
Public CanClose As Boolean 'allows closing of init window

'********************************************************************
' FindKey
'
'   Parameters -
'       Key = the cmd string of a key pressed
'
'   Searches the array of remotes for the given key, if the key exits
'   it returns the associated action ("" if no action is bound to it)
'   and returns "~" if that key is not found
'
'********************************************************************
Public Function FindKey(ByVal Key As String)

    Dim i, j As Integer

    i = 0
    While i < rcount
        j = 0
        While j < StoredRemote(i).bcount
            If Key = StoredRemote(i).Button(j).code Then
                FindKey = StoredRemote(i).Button(j).act
                Exit Function
            End If
            j = j + 1
        Wend
        i = i + 1
    Wend
    
    FindKey = "~"

End Function

'********************************************************************
' FindNode1
'
'   Parameters - NONE
'
'   Searches the TreeView control, starting at the selected item, and
'   finds which position the button is in a given remote.  Returns the
'   number of were it lies in that remote
'
'   EXAMPLE
'       Remote Controls
'           -Sony
'               -Play
'               -Pause
'               -Stop
'
'   Stop would return a 2, Play would return a 0
'
'********************************************************************
Public Function FindNode1()

    Dim i, NodeNum As Integer
    
    While Init.Controlers.SelectedItem.Index <> Init.Controlers.SelectedItem.FirstSibling.Index
        Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Previous
        i = i + 1
    Wend
    NodeNum = i
    While i > 0
        Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Next
        i = i - 1
    Wend
    
    FindNode1 = NodeNum
    
End Function


'********************************************************************
' FindNode2
'
'   Parameters -
'       ButtonNum = the keys position received from FideNode1
'
'   Searches the TreeView control, starting at the selected item, and
'   finds which position the remote is in the Remote Controls tree.
'   Returns the number of were it lies amongst the remotes.  ButtonNum
'   is used to get the selected item back in its original position.
'
'   EXAMPLE
'       Remote Controls
'           -Sony
'               -Play
'               -Pause
'               -Stop
'           -Toshiba
'
'   Toshiba would return a 1, Sony would return a 0
'
'********************************************************************
Public Function FindNode2(ButtonNum As Integer)

    Dim i, NodeNum As Integer
    
    Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Parent
    
    While Init.Controlers.SelectedItem.Index <> Init.Controlers.SelectedItem.FirstSibling.Index
        Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Previous
        i = i + 1
    Wend
    NodeNum = i
    While i > 0
        Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Next
        i = i - 1
    Wend
    
    Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Child
    
    While i < ButtonNum
        Init.Controlers.SelectedItem = Init.Controlers.SelectedItem.Next
        i = i + 1
    Wend
    
    FindNode2 = NodeNum
    
End Function

'********************************************************************
' PerformAction
'
'   Parameters -
'       action = a string signifying which action to perform
'
'   Finds the action in a huge case statement and performs the given task.
'   Different sub-groups are demarcated by the comments.  If one wished
'   to add more actions you would need to add onto this case statement
'   and place the action ("Play WinAmp") in the Actions TreeView in
'   the Init Form.
'
'********************************************************************
Public Sub PerformAction(action As String)

    Dim Point As POINTAPI
    Dim ReturnValue As Double
    Dim RetVal As Long
    Dim num, incr As Integer

    Select Case action
    
   ' ************************************************************************************
   ' ********************************* WINDOWS ACTIONS **********************************
   ' ************************************************************************************
        
        Case "Mouse Left Click"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTDOWN + MOUSE_LEFTUP, Point.X, Point.Y, 0, 0
            
        Case "Mouse Left Down"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTDOWN, Point.X, Point.Y, 0, 0
            
        Case "Mouse Left Up"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_LEFTUP, Point.X, Point.Y, 0, 0
            
        Case "Mouse Right Click"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_RIGHTDOWN + MOUSE_RIGHTUP, Point.X, Point.Y, 0, 0
            
        Case "Mouse Right Down"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_RIGHTDOWN, Point.X, Point.Y, 0, 0
            
        Case "Mouse Right Up"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_RIGHTUP, Point.X, Point.Y, 0, 0
                 
        Case "Mouse Middle Click"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_MIDDLEDOWN + MOUSE_MIDDLEUP, Point.X, Point.Y, 0, 0
            
        Case "Mouse Middle Down"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_MIDDLEDOWN, Point.X, Point.Y, 0, 0
            
        Case "Mouse Middle Up"
            Call GetCursorPos(Point)
            mouse_event MOUSE_ABSOLUTE + MOUSE_MIDDLEUP, Point.X, Point.Y, 0, 0
        
        Case "Mouse Down"
            If SameCount < 4 Then
                incr = 1
            ElseIf SameCount < 8 Then
                incr = 20
            Else
                incr = 50
            End If
            Call GetCursorPos(Point)
            If Point.X < 767 Then
                Y = Point.Y + incr
            Else
                Y = Point.Y
            End If
            Call SetCursorPos(Point.X, Y)

        Case "Mouse Left"
            If SameCount < 4 Then
                incr = 1
            ElseIf SameCount < 8 Then
                incr = 20
            Else
                incr = 50
            End If
            Call GetCursorPos(Point)
            If Point.X > 0 Then
                X = Point.X - incr
            Else
                X = Point.X
            End If
            Call SetCursorPos(X, Point.Y)
            
        Case "Mouse Right"
            If SameCount < 4 Then
                incr = 1
            ElseIf SameCount < 8 Then
                incr = 20
            Else
                incr = 50
            End If
            Call GetCursorPos(Point)
            If Point.X < 1023 Then
                X = Point.X + incr
            Else
                X = Point.X
            End If
            Call SetCursorPos(X, Point.Y)
            
        Case "Mouse Up"
            If SameCount < 4 Then
                incr = 1
            ElseIf SameCount < 8 Then
                incr = 20
            Else
                incr = 50
            End If
            Call GetCursorPos(Point)
            If Point.Y > 0 Then
                Y = Point.Y - incr
            Else
                Y = Point.Y
            End If
            Call SetCursorPos(Point.X, Y)
            
        Case "Cycle Windows"
            Dim h As Long
            If WindowsPointer < WindowsCount Then
                h = SetForegroundWindow(Windows(WindowsPointer))
                h = SetFocus(Windows(WindowsPointer))
                WindowsPointer = WindowsPointer + 1
            Else
                WindowsPointer = 0
                h = SetForegroundWindow(Windows(WindowsPointer))
                h = SetFocus(Windows(WindowsPointer))
                WindowsPointer = WindowsPointer + 1
            End If
            
    ' ***********************************************************************************
    ' ****************************** EXECUTABLE PROGRAMS ********************************
    ' ***********************************************************************************
    
        Case "Open Paint"
            ReturnValue = Shell(PAINT_PATH, vbNormalFocus)
            
        Case "Open/Close Calculator"
            If hCalc = 0 Then
                ReturnValue = Shell(CALCULATOR_PATH, vbNormalFocus)
                hCalc = GetForegroundWindow()
                Windows(WindowsCount) = GetForegroundWindow()
                WindowsCount = WindowsCount + 1
            Else
                RetVal = SetForegroundWindow(hCalc)
                Sleep (10)
                SendKeys ("%{F4}") 'Windows shortcut to close an application
                hCalc = 0
            End If
            
        Case "Open AOL IM"
            ReturnValue = Shell(AIM_PATH, vbNormalFocus)

    ' ***********************************************************************************
    ' ********************************** WINAMP ACTIONS *********************************
    ' ***********************************************************************************
    
        Case "Open/Close WinAmp"
            If hWinAmp = 0 Then
                ReturnValue = Shell(WINAMP_PATH, vbNormalNoFocus)
                ReturnValue = FindWinAmp()
            Else
                WinAmpMessage (WA_CLOSE)
                hWinAmp = 0
            End If
            
        Case "Play WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_PLAY)
            End If
            
        Case "Stop WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_STOP)
            End If
            
        Case "Pause WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_PAUSE)
            End If
            
        Case "Next Track WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_NEXTTRACK)
            End If
            
        Case "Prev Track WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_PREVTRACK)
            End If
                                    
        Case "Fast Forward WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_FASTFORWARD)
            End If
                    
        Case "Rewind WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_REWIND)
            End If
                    
        Case "Volume Up WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_VOLUMEUP)
            End If
                                
        Case "Volume Down WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_VOLUMEDOWN)
            End If
                    
        Case "Repeat WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_TOGGLEREPEAT)
            End If
                    
        Case "Shuffle WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_TOGGLESHUFFLE)
            End If
            
        Case "Jump WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_DIALOGJUMPTOFILE)
            End If
            
        Case "Open File WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_DIALOGOPENFILE)
            End If
            
        Case "Easy Move WinAmp"
            If hWinAmp = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinAmp not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win Amp is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinAmpMessage (WA_TOGGLEEASYMOVE)
            End If
            
    ' ***********************************************************************************
    ' ********************************** WINDVD ACTIONS *********************************
    ' ***********************************************************************************
                     
        Case "Open WinDVD"
            ReturnValue = Shell(WINDVD_PATH, vbNormalFocus)
            ReturnValue = FindWinDVD()
            
        Case "Close WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWinDVD)
                Sleep (10)
                SendKeys ("X") 'WinDVD shortcut to close window
                hWinDVD = 0
            End If
            
        Case "Play WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_PLAY)
            End If
            
        Case "Pause WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_PAUSE)
            End If
            
        Case "Stop WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_STOP)
            End If
            
        Case "Prev Chapter WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_PREVCHAPTER)
            End If
            
        Case "Next Chapter WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_NEXTCHAPTER)
            End If
            
        Case "Fast Forward WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_FASTFORWARD)
            End If
            
        Case "Rewind WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_REWIND)
            End If
            
        Case "Eject WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_EJECT)
            End If
            
        Case "Enter WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_ENTER)
            End If
            
        Case "Volume Up WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_VOLUMEUP)
            End If
            
        Case "Volume Down WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_VOLUMEDOWN)
            End If
            
        Case "Brighter WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_BRIGHTER)
            End If
            
        Case "Darker WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_DARKER)
            End If
            
        Case "Fullscreen WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_FULLSCREEN)
            End If
            
        Case "Menu WinDVD"
            If hWinDVD = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "WinDVD not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Win D V D is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                WinDVDMessage (WD_MENU)
            End If
            
    ' ***********************************************************************************
    ' ********************************** MICROSOFT WORD *********************************
    ' ***********************************************************************************
    
        Case "Open/Close Word"
            If hWord = 0 Then
                ReturnValue = Shell(WORD_PATH, vbNormalFocus)
                hWord = GetForegroundWindow()
                Windows(WindowsCount) = hWord
                WindowsCount = WindowsCount + 1
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("%fx")
                hWord = 0
                WindowsCount = WindowsCount - 1
            End If
            
        Case "Save Word"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("+S")
            End If
            
        Case "Print Word"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("^p")
            End If

        Case "Bold Word"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("^b")
            End If
            
        Case "Italic Word"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("^i")
            End If
            
        Case "Underline Word"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("^u")
            End If
            
        Case "Activate Word Menu"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("{f10}")
            End If
            
        Case "Cycle Word SubMenu"
            If hWord = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Word not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Word is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hWord)
                Sleep (10)
                SendKeys ("^{TAB}")
            End If
            
    ' ***********************************************************************************
    ' ******************************* MICROSOFT POWERPOINT ******************************
    ' ***********************************************************************************
    
        Case "Open/Close Powerpoint"
            If hPP = 0 Then
                ReturnValue = Shell(PP_PATH, vbNormalFocus)
                Sleep (100)
                hPP = GetForegroundWindow()
                Windows(WindowsCount) = hPP
                WindowsCount = WindowsCount + 1
            Else
                RetVal = SetForegroundWindow(hPP)
                Sleep (10)
                SendKeys ("%fx")
                hPP = 0
                WindowsCount = WindowsCount - 1
            End If
            
        Case "Open File Powerpoint"
            If hPP = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Powerpoint not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Powerpoint is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hPP)
                Sleep (10)
                SendKeys ("%fo")
            End If

        Case "Run Powerpoint"
            If hPP = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Powerpoint not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Powerpoint is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hPP)
                Sleep (10)
                SendKeys ("{F5}")
            End If
            
        Case "Previous Slide"
            If hPP = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Powerpoint not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Powerpoint is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                SendKeys ("{LEFT}")
            End If
            
        Case "Next Slide"
            If hPP = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Powerpoint not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Powerpoint is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                SendKeys ("{RIGHT}")
            End If
            
        Case "End Slide Show"
            If hPP = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Powerpoint not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Powerpoint is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                SendKeys ("{ESC}")
            End If
            
    ' ***********************************************************************************
    ' ********************************* INTERNET EXPLORER *******************************
    ' ***********************************************************************************
    
        Case "Open/Close Explorer"
            If hExplorer = 0 Then
                ReturnValue = Shell(EXPLORER_PATH, vbNormalFocus)
                hExplorer = GetForegroundWindow()
                Windows(WindowsCount) = GetForegroundWindow()
                WindowsCount = WindowsCount + 1
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("%fc")
                hExplorer = 0
                WindowsCount = WindowsCount - 1
            End If
            
         Case "Explorer Address"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{F6}")
            End If
            
         Case "Explorer Address List"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{F4}")
            End If
            
         Case "Explorer Home"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("%{HOME}")
            End If
            
         Case "Explorer Next Page"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("%{RIGHT}")
            End If
            
         Case "Explorer Previous Page"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("%{LEFT}")
            End If
            
         Case "Explorer Cycle Items"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{TAB}")
            End If
            
         Case "Explorer Refresh"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{F5}")
            End If
            
         Case "Explorer Top of Page"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{HOME}")
            End If
            
         Case "Explorer End of Page"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("{END}")
            End If
            
         Case "Explorer Search"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("^e")
            End If
            
         Case "Explorer Favorites"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("^i")
            End If
            
         Case "Explorer History"
            If hExplorer = 0 Then
                History.Status.Panels(1).Picture = LoadPicture(STOP_BMP)
                History.Status.Panels(2).Text = "Explorer not open"
                If History.Audio.Value = True Then
'###################### UNCOMMENT FOR SPEECH ########################
'                    Voice.Speak "Explorer is not open", SVSFlagsAsync
'####################################################################
                End If
            Else
                RetVal = SetForegroundWindow(hExplorer)
                Sleep (10)
                SendKeys ("^h")
            End If
            
    ' ***********************************************************************************
    ' ************************************ CHARACTERS ***********************************
    ' ***********************************************************************************
    
        ' These keys are programmed similar to that of a cell phone text messaging
        ' device, as long as you hit the same key within a second it will cycle
        ' through all the letters (a...b...c...A...B...C...a...)
        Case "abcABC"
            If SameCount = 0 Then
                SendKeys "a"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}a"
                    Case 1
                        SendKeys "{BKSP}b"
                    Case 2
                        SendKeys "{BKSP}c"
                    Case 3
                        SendKeys "{BKSP}A"
                    Case 4
                        SendKeys "{BKSP}B"
                    Case 5
                        SendKeys "{BKSP}C"
                End Select
             End If
             
        Case "defDEF"
            If SameCount = 0 Then
                SendKeys "d"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}d"
                    Case 1
                        SendKeys "{BKSP}e"
                    Case 2
                        SendKeys "{BKSP}f"
                    Case 3
                        SendKeys "{BKSP}D"
                    Case 4
                        SendKeys "{BKSP}E"
                    Case 5
                        SendKeys "{BKSP}F"
                End Select
             End If
             
        Case "ghiGHI"
            If SameCount = 0 Then
                SendKeys "g"
            Else
               num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}g"
                    Case 1
                        SendKeys "{BKSP}h"
                    Case 2
                        SendKeys "{BKSP}i"
                    Case 3
                        SendKeys "{BKSP}G"
                    Case 4
                        SendKeys "{BKSP}H"
                    Case 5
                        SendKeys "{BKSP}I"
                End Select
             End If
             
        Case "jklJKL"
            If SameCount = 0 Then
                SendKeys "j"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}j"
                    Case 1
                        SendKeys "{BKSP}k"
                    Case 2
                        SendKeys "{BKSP}l"
                    Case 3
                        SendKeys "{BKSP}J"
                    Case 4
                        SendKeys "{BKSP}K"
                    Case 5
                        SendKeys "{BKSP}L"
                End Select
             End If
             
        Case "mnoMNO"
            If SameCount = 0 Then
                SendKeys "m"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}m"
                    Case 1
                        SendKeys "{BKSP}n"
                    Case 2
                        SendKeys "{BKSP}o"
                    Case 3
                        SendKeys "{BKSP}M"
                    Case 4
                        SendKeys "{BKSP}N"
                    Case 5
                        SendKeys "{BKSP}O"
                End Select
             End If
             
        Case "pqrPQR"
            If SameCount = 0 Then
                SendKeys "p"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}p"
                    Case 1
                        SendKeys "{BKSP}q"
                    Case 2
                        SendKeys "{BKSP}r"
                    Case 3
                        SendKeys "{BKSP}P"
                    Case 4
                        SendKeys "{BKSP}Q"
                    Case 5
                        SendKeys "{BKSP}R"
                End Select
             End If
             
        Case "stuSTU"
            If SameCount = 0 Then
                SendKeys "s"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}s"
                    Case 1
                        SendKeys "{BKSP}t"
                    Case 2
                        SendKeys "{BKSP}u"
                    Case 3
                        SendKeys "{BKSP}S"
                    Case 4
                        SendKeys "{BKSP}T"
                    Case 5
                        SendKeys "{BKSP}U"
                End Select
             End If

        Case "vwxVWX"
            If SameCount = 0 Then
                SendKeys "v"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}v"
                    Case 1
                        SendKeys "{BKSP}w"
                    Case 2
                        SendKeys "{BKSP}x"
                    Case 3
                        SendKeys "{BKSP}V"
                    Case 4
                        SendKeys "{BKSP}W"
                    Case 5
                        SendKeys "{BKSP}X"
                End Select
             End If
             
        Case "yzYZ"
            If SameCount = 0 Then
                SendKeys "m"
            Else
                num = SameCount Mod 4
                Select Case num
                    Case 0
                        SendKeys "{BKSP}y"
                    Case 1
                        SendKeys "{BKSP}z"
                    Case 2
                        SendKeys "{BKSP}Y"
                    Case 3
                        SendKeys "{BKSP}Z"
                End Select
             End If
             
        Case ",.!?:;"
            If SameCount = 0 Then
                SendKeys ","
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP},"
                    Case 1
                        SendKeys "{BKSP}."
                    Case 2
                        SendKeys "{BKSP}!"
                    Case 3
                        SendKeys "{BKSP}?"
                    Case 4
                        SendKeys "{BKSP}:"
                    Case 5
                        SendKeys "{BKSP};"
                End Select
             End If
             
        Case "()[]{}"
            If SameCount = 0 Then
                SendKeys "{(}"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}{(}"
                    Case 1
                        SendKeys "{BKSP}{)}"
                    Case 2
                        SendKeys "{BKSP}{[}"
                    Case 3
                        SendKeys "{BKSP}{]}"
                    Case 4
                        SendKeys "{BKSP}{{}"
                    Case 5
                        SendKeys "{BKSP}{}}"
                End Select
             End If
             
        Case """/\'<>"
            If SameCount = 0 Then
                SendKeys """"
            Else
                num = SameCount Mod 6
                Select Case num
                    Case 0
                        SendKeys "{BKSP}"""
                    Case 1
                        SendKeys "{BKSP}/"
                    Case 2
                        SendKeys "{BKSP}\"
                    Case 3
                        SendKeys "{BKSP}'"
                    Case 4
                        SendKeys "{BKSP}<"
                    Case 5
                        SendKeys "{BKSP}>"
                End Select
             End If
             
        Case "_0"
            SendKeys "0"
            
        Case "_1"
            SendKeys "1"
            
        Case "_2"
            SendKeys "2"
            
        Case "_3"
            SendKeys "3"
            
        Case "_4"
            SendKeys "4"
            
        Case "_5"
            SendKeys "5"
            
        Case "_6"
            SendKeys "6"
            
        Case "_7"
            SendKeys "7"
            
        Case "_8"
            SendKeys "8"
            
        Case "_9"
            SendKeys "9"
            
        Case "F1"
            SendKeys "{F1}"
            
        Case "F2"
            SendKeys "{F2}"
            
        Case "F3"
            SendKeys "{F3}"
            
        Case "F4"
            SendKeys "{F4}"
            
        Case "F5"
            SendKeys "{F5}"
            
        Case "F6"
            SendKeys "{F6}"
            
        Case "F7"
            SendKeys "{F7}"
            
        Case "F8"
            SendKeys "{F8}"
            
        Case "F9"
            SendKeys "{F9}"
            
        Case "F10"
            SendKeys "{F10}"
            
        Case "F11"
            SendKeys "{F11}"
            
        Case "F12"
            SendKeys "{F12}"
            
        Case "Backspace"
            SendKeys "{BKSP}"
            
        Case "Space"
            SendKeys " "
            
        Case "Enter"
            SendKeys "{ENTER}"
            
        Case "Tab"
            SendKeys "{TAB}"
            
        Case "Escape"
            SendKeys "{ESC}"
            
        Case "Left Arrow"
            SendKeys "{LEFT}"
            
        Case "Right Arrow"
            SendKeys "{RIGHT}"
            
        Case "Up Arrow"
            SendKeys "{UP}"
            
        Case "Down Arrow"
            SendKeys "{DOWN}"
            
        Case "Page Up"
            SendKeys "{PGUP}"
            
        Case "Page Down"
            SendKeys "{PGDN}"
                                             
    End Select

End Sub


